@@ -54,7 +54,6 @@
 
 enum
 {
-  SIGNAL_EDITOR_CREATED,
   DOC_SEARCH,
   LAST_SIGNAL
 };
@@ -70,10 +69,6 @@ struct _GladeAppPrivate
 
   GKeyFile *config;             /* The configuration file */
 
-  GtkWindow *transient_parent;  /* If set by glade_app_set_transient_parent(); this
-                                 * will be used as the transient parent of all toplevel
-                                 * GladeWidgets.
-                                 */
   GtkAccelGroup *accel_group;   /* Default acceleration group for this app */
 };
 
@@ -160,13 +155,6 @@ glade_app_finalize (GObject * app)
 /*****************************************************************
  *                    GladeAppClass                              *
  *****************************************************************/
-static void
-glade_app_signal_editor_created_default (GladeApp * app,
-                                         GladeSignalEditor * signal_editor)
-{
-  glade_signal_editor_construct_signals_list (signal_editor);
-}
-
 static GKeyFile *
 glade_app_config_load (GladeApp * app)
 {
@@ -313,36 +301,18 @@ glade_app_init (GladeApp * app)
 static void
 glade_app_class_init (GladeAppClass * klass)
 {
-  GObjectClass *object_class;
-
-  object_class = G_OBJECT_CLASS (klass);
+	GObjectClass *object_class;
+	
+	object_class = G_OBJECT_CLASS (klass);
+	
+	object_class->constructor  = glade_app_constructor;
+	object_class->dispose      = glade_app_dispose;
+	object_class->finalize     = glade_app_finalize;
 
   object_class->constructor = glade_app_constructor;
   object_class->dispose = glade_app_dispose;
   object_class->finalize = glade_app_finalize;
 
-  klass->signal_editor_created = glade_app_signal_editor_created_default;
-
-  /**
-   * GladeApp::signal-editor-created:
-   * @gladeapp: the #GladeApp which received the signal.
-   * @signal_editor: the new #GladeSignalEditor.
-   *
-   * Emitted when a new signal editor created.
-   * A tree view is created in the default handler.
-   * Connect your handler before the default handler for setting a custom column or renderer
-   * and after it for connecting to the tree view signals
-   */
-  glade_app_signals[SIGNAL_EDITOR_CREATED] =
-      g_signal_new ("signal-editor-created",
-                    G_TYPE_FROM_CLASS (object_class),
-                    G_SIGNAL_RUN_LAST,
-                    G_STRUCT_OFFSET (GladeAppClass,
-                                     signal_editor_created),
-                    NULL, NULL,
-                    glade_marshal_VOID__OBJECT, G_TYPE_NONE, 1, G_TYPE_OBJECT);
-
-
   /**
    * GladeApp::doc-search:
    * @gladeeditor: the #GladeEditor which received the signal.
@@ -482,28 +452,6 @@ glade_app_config_save ()
   return 0;
 }
 
-void
-glade_app_set_transient_parent (GtkWindow * parent)
-{
-  GladeApp *app;
-
-  g_return_if_fail (GTK_IS_WINDOW (parent));
-
-  app = glade_app_get ();
-  app->priv->transient_parent = parent;
-}
-
-GtkWindow *
-glade_app_get_transient_parent (void)
-{
-  GtkWindow *parent;
-  GladeApp *app = glade_app_get ();
-
-  parent = app->priv->transient_parent;
-
-  return parent;
-}
-
 GladeApp *
 glade_app_get (void)
 {
