@@ -54,9 +54,6 @@ struct _GladeAppClass
 {
   GObjectClass parent_class;
 
-  /* signals */
-  void   (* signal_editor_created) (GladeApp *app, GladeSignalEditor *signal_editor);
-
   void   (* glade_reserved1)   (void);
   void   (* glade_reserved2)   (void);
   void   (* glade_reserved3)   (void);
@@ -65,7 +62,6 @@ struct _GladeAppClass
   void   (* glade_reserved6)   (void);
 };
 
-
 GType              glade_app_get_type             (void) G_GNUC_CONST;
 
 GladeApp*          glade_app_new                  (void);
@@ -89,9 +85,6 @@ GladeProject*      glade_app_get_project_by_path  (const gchar   *project_path);
 void               glade_app_set_window           (GtkWidget     *window);
 GtkWidget*         glade_app_get_window           (void);
  
-void               glade_app_set_transient_parent (GtkWindow     *parent);
-GtkWindow         *glade_app_get_transient_parent (void);
- 
 void               glade_app_set_accel_group      (GtkAccelGroup *accel_group);
 GtkAccelGroup     *glade_app_get_accel_group      (void);
 
