@@ -1795,7 +1795,7 @@ glade_base_editor_init (GladeBaseEditor * editor)
                                          e->table);
 
   /* Signal Editor */
-  e->signal_editor = glade_signal_editor_new (NULL);
+  e->signal_editor = glade_signal_editor_new ();
   gtk_widget_show (GTK_WIDGET (e->signal_editor));
   gtk_widget_set_size_request (GTK_WIDGET (e->signal_editor), -1, 96);
   gtk_paned_pack2 (GTK_PANED (paned), GTK_WIDGET (e->signal_editor), FALSE,
@@ -2175,7 +2175,7 @@ glade_base_editor_help (GtkButton * button, gchar * markup)
 {
   GtkWidget *dialog;
 
-  dialog = gtk_message_dialog_new (glade_app_get_transient_parent (),
+  dialog = gtk_message_dialog_new (GTK_WINDOW (glade_app_get_window ()),
                                    GTK_DIALOG_DESTROY_WITH_PARENT,
                                    GTK_MESSAGE_INFO, GTK_BUTTONS_CLOSE, " ");
 
