@@ -34,12 +34,13 @@ static void glade_tool_button_editor_editable_init (GladeEditableIface * iface);
 static void glade_tool_button_editor_grab_focus (GtkWidget * widget);
 
 
+static GladeEditableIface *parent_editable_iface;
+
 G_DEFINE_TYPE_WITH_CODE (GladeToolButtonEditor, glade_tool_button_editor,
                          GTK_TYPE_VBOX,
                          G_IMPLEMENT_INTERFACE (GLADE_TYPE_EDITABLE,
                                                 glade_tool_button_editor_editable_init));
 
-
 static void
 glade_tool_button_editor_class_init (GladeToolButtonEditorClass * klass)
 {
@@ -55,30 +56,6 @@ glade_tool_button_editor_init (GladeToolButtonEditor * self)
 {
 }
 
-static void
-project_changed (GladeProject * project,
-                 GladeCommand * command,
-                 gboolean execute, GladeToolButtonEditor * button_editor)
-{
-  if (button_editor->modifying ||
-      !gtk_widget_get_mapped (GTK_WIDGET (button_editor)))
-    return;
-
-  /* Reload on all commands */
-  glade_editable_load (GLADE_EDITABLE (button_editor),
-                       button_editor->loaded_widget);
-}
-
-
-static void
-project_finalized (GladeToolButtonEditor * button_editor,
-                   GladeProject * where_project_was)
-{
-  button_editor->loaded_widget = NULL;
-
-  glade_editable_load (GLADE_EDITABLE (button_editor), NULL);
-}
-
 static void
 glade_tool_button_editor_load (GladeEditable * editable, GladeWidget * widget)
 {
@@ -87,34 +64,14 @@ glade_tool_button_editor_load (GladeEditable * editable, GladeWidget * widget)
   GladeToolButtonImageMode image_mode = 0;
   GList *l;
 
+  /* Chain up to default implementation */
+  parent_editable_iface->load (editable, widget);
+
   button_editor->loading = TRUE;
 
-  /* Since we watch the project */
-  if (button_editor->loaded_widget)
-    {
-      g_signal_handlers_disconnect_by_func (glade_widget_get_project (button_editor->loaded_widget),
-                                            G_CALLBACK (project_changed),
-                                            button_editor);
-
-      /* The widget could die unexpectedly... */
-      g_object_weak_unref (G_OBJECT (glade_widget_get_project (button_editor->loaded_widget)),
-                           (GWeakNotify) project_finalized, button_editor);
-    }
-
   /* Mark our widget... */
   button_editor->loaded_widget = widget;
 
-  if (button_editor->loaded_widget)
-    {
-      /* This fires for undo/redo */
-      g_signal_connect (glade_widget_get_project (button_editor->loaded_widget),
-                        "changed", G_CALLBACK (project_changed), button_editor);
-
-      /* The widget/project could die unexpectedly... */
-      g_object_weak_ref (G_OBJECT (glade_widget_get_project (button_editor->loaded_widget)),
-                         (GWeakNotify) project_finalized, button_editor);
-    }
-
   /* load the embedded editable... */
   if (button_editor->embed)
     glade_editable_load (GLADE_EDITABLE (button_editor->embed), widget);
@@ -184,7 +141,7 @@ standard_label_toggled (GtkWidget * widget,
       (GTK_TOGGLE_BUTTON (button_editor->standard_label_radio)))
     return;
 
-  button_editor->modifying = TRUE;
+  glade_editable_block (GLADE_EDITABLE (button_editor));
 
   glade_command_push_group (_("Setting %s to use standard label text"),
                             glade_widget_get_name (button_editor->loaded_widget));
@@ -203,7 +160,7 @@ standard_label_toggled (GtkWidget * widget,
 
   glade_command_pop_group ();
 
-  button_editor->modifying = FALSE;
+  glade_editable_unblock (GLADE_EDITABLE (button_editor));
 
   /* reload buttons and sensitivity and stuff... */
   glade_editable_load (GLADE_EDITABLE (button_editor),
@@ -222,7 +179,7 @@ custom_label_toggled (GtkWidget * widget, GladeToolButtonEditor * button_editor)
       (GTK_TOGGLE_BUTTON (button_editor->custom_label_radio)))
     return;
 
-  button_editor->modifying = TRUE;
+  glade_editable_block (GLADE_EDITABLE (button_editor));
 
   glade_command_push_group (_("Setting %s to use a custom label widget"),
                             glade_widget_get_name (button_editor->loaded_widget));
@@ -235,7 +192,7 @@ custom_label_toggled (GtkWidget * widget, GladeToolButtonEditor * button_editor)
 
   glade_command_pop_group ();
 
-  button_editor->modifying = FALSE;
+  glade_editable_unblock (GLADE_EDITABLE (button_editor));
 
   /* reload buttons and sensitivity and stuff... */
   glade_editable_load (GLADE_EDITABLE (button_editor),
@@ -254,7 +211,7 @@ stock_toggled (GtkWidget * widget, GladeToolButtonEditor * button_editor)
       (GTK_TOGGLE_BUTTON (button_editor->stock_radio)))
     return;
 
-  button_editor->modifying = TRUE;
+  glade_editable_block (GLADE_EDITABLE (button_editor));
 
   glade_command_push_group (_("Setting %s to use an image from stock"),
                             glade_widget_get_name (button_editor->loaded_widget));
@@ -273,7 +230,7 @@ stock_toggled (GtkWidget * widget, GladeToolButtonEditor * button_editor)
 
   glade_command_pop_group ();
 
-  button_editor->modifying = FALSE;
+  glade_editable_unblock (GLADE_EDITABLE (button_editor));
 
   /* reload buttons and sensitivity and stuff... */
   glade_editable_load (GLADE_EDITABLE (button_editor),
@@ -293,7 +250,7 @@ icon_toggled (GtkWidget * widget, GladeToolButtonEditor * button_editor)
       (GTK_TOGGLE_BUTTON (button_editor->icon_radio)))
     return;
 
-  button_editor->modifying = TRUE;
+  glade_editable_block (GLADE_EDITABLE (button_editor));
 
   glade_command_push_group (_("Setting %s to use an image from the icon theme"),
                             glade_widget_get_name (button_editor->loaded_widget));
@@ -312,7 +269,7 @@ icon_toggled (GtkWidget * widget, GladeToolButtonEditor * button_editor)
 
   glade_command_pop_group ();
 
-  button_editor->modifying = FALSE;
+  glade_editable_unblock (GLADE_EDITABLE (button_editor));
 
   /* reload buttons and sensitivity and stuff... */
   glade_editable_load (GLADE_EDITABLE (button_editor),
@@ -331,7 +288,7 @@ custom_toggled (GtkWidget * widget, GladeToolButtonEditor * button_editor)
       (GTK_TOGGLE_BUTTON (button_editor->custom_radio)))
     return;
 
-  button_editor->modifying = TRUE;
+  glade_editable_block (GLADE_EDITABLE (button_editor));
 
   glade_command_push_group (_("Setting %s to use an image from the icon theme"),
                             glade_widget_get_name (button_editor->loaded_widget));
@@ -350,7 +307,7 @@ custom_toggled (GtkWidget * widget, GladeToolButtonEditor * button_editor)
 
   glade_command_pop_group ();
 
-  button_editor->modifying = FALSE;
+  glade_editable_unblock (GLADE_EDITABLE (button_editor));
 
   /* reload buttons and sensitivity and stuff... */
   glade_editable_load (GLADE_EDITABLE (button_editor),
@@ -370,6 +327,8 @@ glade_tool_button_editor_set_show_name (GladeEditable * editable,
 static void
 glade_tool_button_editor_editable_init (GladeEditableIface * iface)
 {
+  parent_editable_iface = g_type_default_interface_peek (GLADE_TYPE_EDITABLE);
+
   iface->load = glade_tool_button_editor_load;
   iface->set_show_name = glade_tool_button_editor_set_show_name;
 }
